seconds_to_natural_delta: Takes in a number of seconds and computes a "human" delta
Description
Takes in a number of seconds and computes a "human" delta
Usage
seconds_to_natural_delta(seconds, use_months = TRUE)
Arguments
seconds
A positive number of seconds
use_months
Boolean whether we should (imprecisely) use months as a unit